@@ -85,7 +85,9 @@ class AIRClient:
         for id, field in zip(field_names, fields):
             field_type = self._config.data_fields_defs[id]["python-type"]
             ret_val = parse_json_if_json(field)
-            if isinstance(ret_val, list):  # this means multiple=True
+            if field_type is bool:  # NB: bool(string) is True for all non-empty strings...:
+                return_fields.append(is_string_truthy(ret_val))
+            elif isinstance(ret_val, list):  # this means multiple=True
                 return_fields.append(list(map(field_type, ret_val)))
             else:
                 return_fields.append(field_type(ret_val))
@@ -102,6 +104,7 @@ class AIRClient:
             "str": str,
             "int": int,
             "float": float,
+            "bool": bool,
             "TimeSeries": str,
             "Asset": str,
         }
